@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import json
-from pagador.acesso.externo import FormatoDeEnvio
+from pagador.acesso.externo import FormatoDeEnvio, TipoMetodo
 from pagador.retorno.models import SituacaoPedido
 from pagador.retorno.registro import RegistroBase
 
@@ -31,6 +31,7 @@ class Registro(RegistroBase):
         self.exige_autenticacao = True
         self.processa_resposta = True
         self.tipo = tipo
+        self.metodo_request = TipoMetodo.get
         self.formato_de_envio = FormatoDeEnvio.json
 
     @property
@@ -42,10 +43,10 @@ class Registro(RegistroBase):
 
     @property
     def pedido_numero(self):
-        if self.retorno_de_notificacao:
-            return self.item_topico["external_reference"]
         if "external_reference" in self.dados:
             return self.dados["external_reference"]
+        if self.retorno_de_notificacao:
+            return self.item_topico["external_reference"]
         return None
 
     @property
@@ -87,7 +88,7 @@ class Registro(RegistroBase):
 
     @property
     def alterar_situacao(self):
-        return True
+        return self.chave_topico in self.dados and self.item_topico
 
     @property
     def retorno_de_preferencia(self):
@@ -105,7 +106,7 @@ class Registro(RegistroBase):
 
     @property
     def deve_gravar_dados_de_pagamento(self):
-        return self.obter_dados_do_gateway
+        return self.obter_dados_do_gateway and self.chave_topico in self.dados and self.item_topico
 
     @property
     def valores_de_pagamento(self):
@@ -128,7 +129,10 @@ class Registro(RegistroBase):
         if self.topico == Topicos.pagamento:
             return self.dados[self.chave_topico]
         if self.topico == Topicos.ordem_pagamento:
-            return self.dados[self.chave_topico][0]
+            try:
+                return self.dados[self.chave_topico][0]
+            except IndexError:
+                return {}
 
     @property
     def topico(self):
